==> haskell-fast-logger-3.2.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.3
visibility:           public
id:                   fast-logger-3.2.3-2PLNu4khW917eOxjQFwyeS
key:                  fast-logger-3.2.3-2PLNu4khW917eOxjQFwyeS
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  fd7a89e962b54ef7514ea25b21f14650
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.3-2PLNu4khW917eOxjQFwyeS
depends:
    array-0.5.4.0 auto-update-0.1.6-ImzSmIgtqtK5NclgP8vMHq
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    easy-file-0.2.5-JgBIKiwnE0PDGA0XabB9t6 filepath-1.4.2.2 stm-2.5.1.0
    text-2.0.2 unix-compat-0.7.4-HkeMBjDm0rZC7ERiJ32kv5
    unix-time-0.4.17-2FWoR4BhUtV1gQjhwYwmuP

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.2.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.3
visibility:           public
id:                   fast-logger-3.2.3-Cvnd7Suknvg17POl4vkZ6k
key:                  fast-logger-3.2.3-Cvnd7Suknvg17POl4vkZ6k
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  b91f20648021c0c6e9f0894980bd8373
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fast-logger-3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.3-Cvnd7Suknvg17POl4vkZ6k
depends:
    array-0.5.4.0 auto-update-0.1.6-TVuXptZc6BKI0rZZ7cvie base-4.17.2.1
    bytestring-0.11.5.3 directory-1.3.7.1
    easy-file-0.2.5-AvbcR17Grr78wIeScHoydl filepath-1.4.2.2 stm-2.5.1.0
    text-2.0.2 unix-compat-0.7.4-HSgadBBXSpB6KNshGA8sWV
    unix-time-0.4.17-1Ell0sUeWuQEyJUcvn5AN9

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
